#ifndef NT2_INCLUDE_FUNCTIONS_ELLINT_1_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ELLINT_1_HPP_INCLUDED

#include <nt2/elliptic/include/functions/ellint_1.hpp>

#endif
